#[non_exhaustive]pub enum Operation<'a> {
Read,
Publish {
name: &'a str,
vers: &'a str,
cksum: &'a str,
},
Yank {
name: &'a str,
vers: &'a str,
},
Unyank {
name: &'a str,
vers: &'a str,
},
Owners {
name: &'a str,
},
Unknown,
}Expand description
A record of what kind of operation is happening that we should generate a token for.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Read
The user is attempting to fetch a crate.
Publish
The user is attempting to publish a crate.
Fields
Yank
The user is attempting to yank a crate.
Unyank
The user is attempting to unyank a crate.
Owners
The user is attempting to modify the owners of a crate.
Unknown